#include <gtk/gtk.h>

GtkWidget* main_dlg_new();

void
on_apply_clicked                       (GtkButton       *button,
                                        gpointer         user_data);

void
on_font_changed                        (GtkFontButton   *fontbutton,
                                        gpointer         user_data);

void
on_install_theme_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_remove_theme_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_cursor_size_changed                 (GtkHScale       *cursorsizescale,
                                        gpointer         user_data);

void
on_tb_style_changed                    (GtkComboBox     *combobox,
                                        gpointer         user_data);
